# coding: utf-8

# flake8: noqa

"""
    EmployeeEFCrud

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from EFCrud.api.auth_api import AuthApi
from EFCrud.api.employees_api import EmployeesApi
from EFCrud.api.features_api import FeaturesApi
from EFCrud.api.roles_api import RolesApi

# import ApiClient
from EFCrud.api_response import ApiResponse
from EFCrud.api_client import ApiClient
from EFCrud.configuration import Configuration
from EFCrud.exceptions import OpenApiException
from EFCrud.exceptions import ApiTypeError
from EFCrud.exceptions import ApiValueError
from EFCrud.exceptions import ApiKeyError
from EFCrud.exceptions import ApiAttributeError
from EFCrud.exceptions import ApiException

# import models into sdk package
from EFCrud.models.employee import Employee
from EFCrud.models.roles import Roles
from EFCrud.models.user import User
from EFCrud.models.user_roles import UserRoles
from EFCrud.models.userdto import Userdto



# flake8: noqa

# import apis into api package
from EFCrud.api.auth_api import AuthApi
from EFCrud.api.employees_api import EmployeesApi
from EFCrud.api.features_api import FeaturesApi
from EFCrud.api.roles_api import RolesApi




# coding: utf-8

"""
    EmployeeEFCrud

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from EFCrud.models.employee import Employee

class TestEmployee(unittest.TestCase):
    """Employee unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Employee:
        """Test Employee
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Employee`
        """
        model = Employee()
        if include_optional:
            return Employee(
                employee_id = 56,
                name = '',
                age = 56,
                department = '',
                experience = 56,
                blood_group = '',
                father_name = '',
                is_deleted = True,
                is_active = True,
                date_of_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_of_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                roles = '',
                is_supervisor = True,
                is_manager = True
            )
        else:
            return Employee(
        )
        """

    def testEmployee(self):
        """Test Employee"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
